@@ -7,7 +7,7 @@ import time
 
 from config_rss import *
 
-from rumpy import RumClient
+from rumpy import FullNode
 
 sys.path.insert(0, RUMPY_PATH)
 sys.path.insert(0, MIXIN_SDK_PATH)
@@ -36,7 +36,7 @@ class BlazeBot:
     def __init__(self, db_name=None):
         self.config = AppConfig.from_file(MIXIN_KEYSTORE_FILE)
         self.db = BaseDB(db_name or DB_NAME, echo=False, reset=False)
-        self.rum = RumClient(port=RUM_PORT)
+        self.rum = FullNode(port=RUM_PORT)
         self.groups = self.check_groups()
 
     def check_groups(self):
@@ -47,7 +47,7 @@ class BlazeBot:
                 self.rum.group_id = _gid
                 groups[_gid] = {
                     "group_id": _gid,
-                    "group_name": self.rum.group.seed().get("group_name"),
+                    "group_name": self.rum.api.seed().get("group_name"),
                     "minutes": RSS_BOT_COMMANDS[k].get("minutes") or DEFAULT_MINUTES,
                 }
         return groups
