@@ -3,6 +3,7 @@ import dataclasses
 import json
 import logging
 import os
+import sys
 import time
 import uuid
 from typing import Any, Dict, List
@@ -21,6 +22,19 @@ TRX_TYPES = [
     "ASK_PEERID",
 ]
 
+API_PAYMENT_GATEWAY: str = "https://prs-bp2.press.one/api"
+
+
+@dataclasses.dataclass
+class ApiBaseURLS:
+    FULL_NODE: str
+    LIGHT_NODE: str
+    PAYMENT_GATEWAY = API_PAYMENT_GATEWAY
+
+    def __init__(self, port=None, host="127.0.0.1"):
+        self.FULL_NODE = f"https://{host}:{port}"
+        self.LIGHT_NODE = f"https://{host}:{port}/nodesdk_api"
+
 
 @dataclasses.dataclass
 class NodeInfo:
